@@ -40,6 +40,7 @@ case "confirm":
     $title=translate("delete album");
     break;
 case "display":
+    # display is a redirect to albums.php
     $title = translate("Display album");
     $view=new album\view\display($request, $album);
     echo $view->view();
@@ -57,7 +58,7 @@ case "redirect":
     end;
     break;
 case "notfound":
-    $view=new person\view\notfound($request);
+    $view=new album\view\notfound($request);
     break;
 }
 
