@@ -42,10 +42,11 @@ class breadcrumb {
      * action or a safe action ("edit", "delete", etc would be unsafe)
      * @param string title
      * @param string action (display, edit, delete, etc.)
+     * @todo calls $_SERVER directly
      */
     public function __construct($title, $action) {
         $user=user::getCurrent();
-        $link=htmlentities($_SERVER["REQUEST_URI"]);
+        $url=htmlentities($_SERVER["REQUEST_URI"]);
         $page=array_reverse(explode("/",$_SERVER['PHP_SELF']));
         $page=$page[0];
 
@@ -57,7 +58,7 @@ class breadcrumb {
         $numCrumbs = count(static::$crumbs);
 
         if (isset($title) && $numCrumbs < 100 && in_array($action, $crumbActions, true)) {
-            if ($numCrumbs == 0 || (!strpos($link, "_crumb="))) {
+            if ($numCrumbs == 0 || (!strpos($url, "_crumb="))) {
 
                 // if title is the same remove last and add new
                 if ($numCrumbs > 0 && static::getLast()->getTitle()==$title) {
@@ -66,28 +67,36 @@ class breadcrumb {
                     $numCrumbs++;
                 }
 
-                $question = strpos($link, "?");
+                $question = strpos($url, "?");
                 if ($question > 0) {
-                    $link =
-                        substr($link, 0, $question) ."?_crumb=$numCrumbs&amp;" .
-                        substr($link, $question + 1);
+                    $url =
+                        substr($url, 0, $question) ."?_crumb=$numCrumbs&amp;" .
+                        substr($url, $question + 1);
                 } else {
-                    $link .= "?_crumb=$numCrumbs";
+                    $url .= "?_crumb=$numCrumbs";
                 }
 
                 $this->title=$title;
-                $this->link=$link;
+                $this->url=$url;
                 static::$crumbs[] = $this;
             }
         }
     }
 
+    /**
+     * Get the title of the breadcrumb
+     * @return string title
+     */
     public function getTitle() {
         return $this->title;
     }
 
-    public function getLink() {
-        return $this->link;
+    /**
+     * Get the URL of the breadcrumb
+     * @return string url
+     */
+    public function getURL() {
+        return $this->url;
     }
 
     /**
