@@ -99,6 +99,17 @@ class category extends zophTreeTable implements Organizer {
         $qry->execute();
     }
 
+    /**
+     * Can user edit this category
+     * No specific user rights, so we simply return whether
+     * this user can edit categories or not.
+     * @param user user
+     * @return bool can edit
+     */
+    public function isWritableBy(user $user) {
+        return $user->canEditOrganizers();
+    }
+
     /**
      * Delete category
      */
