@@ -88,7 +88,7 @@ class arguments {
         $args["pplace"]=array();
 
         /*
-          Used short arguments: A C D H I N P V a c d f g h i l n p r t u v w
+          Used short arguments: A C D H I N P V X a c d f g h i l n p r t u v w
         */
         $size=sizeof($argv);
         for ($i=0; $i<$size; $i++) {
@@ -309,6 +309,11 @@ class arguments {
             case "--help":
                 static::$command="help";
                 break;
+            case "-X":
+            case "--xmp":
+            case "--XMP":
+                $args["_xmp"] = true;
+                break;
             case "-v":
             case "--verbose":
                 $verbose=conf::get("import.cli.verbose");
@@ -498,6 +503,9 @@ class arguments {
                     $vars[$field]=$value;
                 }
                 break;
+            case "_xmp":
+                $vars["_xmp"] = true;
+                break;
             case "_configitem":
             case "_configvalue":
             case "_configdefault":
