@@ -30,6 +30,8 @@ use person;
 use user;
 use conf\conf;
 use import\cli as cliimport;
+use xmp\reader as xmpreader;
+use xmp\decoder as xmpdecoder;
 
 /**
  * Controller class for the CLI
@@ -237,6 +239,26 @@ class cli {
                 foreach (array_unique($this->files) as $file) {
                     $photo=new photo();
                     $photo->file["orig"]=$file;
+
+                    if (isset($vars["_xmp"])) {
+                        $xmp = new xmpReader($file);
+                        $data=new xmpdecoder($xmp->getXMP());
+                        foreach($data->getSubjects() as $subject) {
+                            $categories = category::getByName($subject);
+                            $category = array_pop($categories);
+                            if ($category instanceof category) {
+                                if (!isset($photo->_category_id)) {
+                                    $photo->_category_id=array();
+                                }
+                                $photo->_category_id[]=$category->getId();
+                            }
+                        }
+                        $rating = $data->getRating();
+                        if ($rating) {
+                            $photo->_rate=$rating;
+                        }
+                    }
+
                     $photos[]=$photo;
                 }
             } else {
