@@ -29,6 +29,7 @@ use db\param;
 
 use template\block;
 
+use zophCode\parser as zophCodeParser;
 /**
  * A class corresponding to the comments table.
  *
@@ -95,7 +96,7 @@ class comment extends zophTable {
         $date=$this->get("comment_date");
         $changed=$this->get("timestamp");
 
-        $zophcode = new zophCode\parser($this->get("comment"), array("b", "i", "u"));
+        $zophcode = new zophCodeParser($this->get("comment"), array("b", "i", "u"));
         $comment="<div>" . $zophcode . "</div>";
 
         return array(
@@ -180,7 +181,7 @@ class comment extends zophTable {
             "subject"       => $this->get("subject"),
             "commentdate"   => $this->get("comment_date"),
             "userlink"      => $this->getUserLink(),
-            "zophcode"      => new zophCode\parser($this->get("comment"), array("b", "i", "u")),
+            "zophcode"      => new zophCodeParser($this->get("comment"), array("b", "i", "u")),
             "actionlinks"   => null
 
         );
