@@ -198,13 +198,13 @@ class confDefault extends conf {
             "You can also set it to \"autodetect\", which means Zoph will lookup the " .
             "name of the Unix user starting the CLI client and tries to find that user's " .
             "name in the Zoph database.");
-        $intUserCli->addOption(0, "Autodetect");
+        $intUserCli->addOption("0", "Autodetect");
         foreach ($users as $usr) {
             if ($usr->isAdmin()) {
-                $intUserCli->addOption($usr->getId(), $usr->getName());
+                $intUserCli->addOption((string)$usr->getId(), $usr->getName());
             }
         }
-        $intUserCli->setDefault(0);
+        $intUserCli->setDefault("1");
         $interface[]=$intUserCli;
 
         $intUserRemote = new checkbox();
@@ -713,6 +713,16 @@ class confDefault extends conf {
     private static function getConfigShare() {
         $share = new collection();
 
+        $shareURLoverride = new text();
+        $shareURLoverride->setName("share.url.override");
+        $shareURLoverride->setLabel("URL override");
+        $shareURLoverride->setDesc("In most cases, Zoph can determine the URL it is " .
+            "reachable on. If the URL it automatically determines is incorrect, " .
+            "you can override it here. Specify a full URL, including http or https.");
+        $shareURLoverride->setRegex("^$|^http(s?):\/\/[a-zA-Z0-9\.\/~]+$");
+        $shareURLoverride->setDefault("");
+        $share[]=$shareURLoverride;
+
         $shareEnable = new checkbox();
         $shareEnable->setName("share.enable");
         $shareEnable->setLabel("Sharing");
