@@ -30,6 +30,7 @@ use conf\conf;
 use template\template;
 
 use xmp\reader as xmpreader;
+use xmp\decoder as xmpdecoder;
 
 /**
  * This class holds all the functions for uploading and importing images
@@ -398,9 +399,12 @@ class web extends base {
 
         $dir=conf::get("path.images") . DIRECTORY_SEPARATOR . conf::get("path.upload");
         $files = file::getFromDir($dir);
+
         foreach ($files as $file) {
             unset($icon);
             unset($status);
+            unset($rating);
+            $subject = null;
 
             $md5=$file->getMD5();
 
@@ -414,8 +418,9 @@ class web extends base {
                   file_exists($dir . DIRECTORY_SEPARATOR . $mid)) {
                     $status="done";
                     $xmp = new xmpreader($file);
-                    $data=$xmp->getXMP()[0];
-                    $subject = (array) $data->getRDFDescription("dc:subject");
+                    $data=new xmpdecoder($xmp->getXMP());
+                    $subjects = $data->getSubjects();
+                    $rating = $data -> getRating();
                 } else {
                     $icon=template::getImage("icons/pause.png");
                     $status="waiting";
@@ -449,14 +454,18 @@ class web extends base {
                 $xmlfile->appendChild($xmlstatus);
             }
 
-            if (is_array($subject) && sizeof($subject) > 0) {
+            if (isset($subjects) && is_array($subjects) && sizeof($subjects) > 0) {
                 $xmlsubjects=$xml->createElement("subjects");
-                foreach($subject as $subj) {
-                    $xmlsubjects->appendChild($xml->createElement("subject", $subj));
+                foreach($subjects as $subject) {
+                    $xmlsubjects->appendChild($xml->createElement("subject", $subject));
                 }
                 $xmlfile->appendChild($xmlsubjects);
             }
 
+            if (isset($rating)) {
+                $xmlfile->appendChild($xml->createElement("rating", $rating));
+            }
+
             $root->appendChild($xmlfile);
         }
         $xml->appendChild($root);
