@@ -243,7 +243,7 @@ class person extends zophTable implements Organizer {
         $qry->addParams($params);
         $qry->execute();
 
-        parent::delete(array("photo_people"));
+        parent::delete(array("photo_people", "circles_people"));
     }
 
     /**
@@ -375,11 +375,14 @@ class person extends zophTable implements Organizer {
         $father=$this->getFather();
         $spouse=$this->getSpouse();
 
+        $dob = new Time($this->get("dob"));
+        $dod = new Time($this->get("dod"));
+
         $display=array(
             translate("called") => e($this->get("called")),
             translate("full name") => $this->getFullName(),
-            translate("date of birth") => create_date_link(e($this->get("dob"))),
-            translate("date of death") => create_date_link(e($this->get("dod"))),
+            translate("date of birth") => $dob->getLink(),
+            translate("date of death") => $dod->getLink(),
             translate("gender") => e($this->getGender()));
         if ($mother instanceof person) {
             $display[translate("mother")] = $mother->getLink();
