@@ -102,7 +102,7 @@ abstract class common {
 
             $cells = $cols * $rows;
 
-            $upQs = update_query_string($this->request->getRequestVars(), null, null, $ignore);
+            $upQs = http_build_query($this->request->getUpdatedVars(null, null, $ignore));
 
             if ($cells) {
                 $off = $cells * floor($offset / ($cells));
