@@ -131,20 +131,28 @@ class rating extends zophTable {
             return;
         }
 
+        if (isset($_SERVER["REMOTE_ADDR"])) {
+            $ip = e($_SERVER["REMOTE_ADDR"]);
+        } else {
+            // For CLI access
+            $host = gethostname();
+            $ip = e(gethostbyname($host));
+        }
+
         $current_ratings=static::getRatings($photo, $user);
 
         if (sizeof($current_ratings) > 0) {
             $cur_rating=array_pop($current_ratings);
 
             $cur_rating->set("rating", (int) $rating);
-            $cur_rating->set("ipaddress", e($_SERVER["REMOTE_ADDR"]));
+            $cur_rating->set("ipaddress", $ip);
             $cur_rating->update();
         } else {
             $new_rating=new rating();
             $new_rating->set("photo_id", (int) $photo->getId());
             $new_rating->set("user_id", (int) $user->getId());
             $new_rating->set("rating", (int) $rating);
-            $new_rating->set("ipaddress", e($_SERVER["REMOTE_ADDR"]));
+            $new_rating->set("ipaddress", $ip);
             $new_rating->insert();
         }
     }
