@@ -48,16 +48,43 @@ class colorScheme extends \zophTable {
     /** @var colorScheme the currently loaded scheme */
     private static $current=null;
 
+
+    public function __construct($id=0) {
+        parent::__construct($id);
+        if (!$id) {
+            foreach(self::getDefaults() as $name => $value) {
+                $this->set($name, $value);
+            }
+            $this->removeOctothorpe();
+        }
+    }
+
+   /**
+    * Insert the color scheme in the db
+    */
+    public function insert() {
+        $this->removeOctothorpe();
+        parent::insert();
+    }
+
    /**
     * Update the color scheme in the db
     */
     public function update() {
-        foreach ($this->fields as $field => $value) {
-            $this->set($field, str_replace("#", "", $value));
-        }
+        $this->removeOctothorpe();
         parent::update();
     }
 
+    public function getName() {
+        return $this->get("name");
+    }
+
+    public function getDisplayArray() {
+        $da = parent::getDisplayArray();
+        unset($da["Name"]);
+        return $da;
+    }
+
     /**
      * Get color from current color scheme
      * or fall back to default
@@ -73,7 +100,7 @@ class colorScheme extends \zophTable {
     }
 
     /**
-     * Get all colours from the current schem
+     * Get all colours from the current scheme
      * @return array of name => value pairs
      */
     public function getColors() {
@@ -88,6 +115,12 @@ class colorScheme extends \zophTable {
         return $colors;
     }
 
+
+    private function removeOctothorpe() {
+        foreach ($this->fields as $field => $value) {
+            $this->set($field, str_replace("#", "", $value));
+        }
+    }
     /**
      * Define a default for each color
      * for now, this is a fallback for whenever no color scheme has been loaded,
@@ -101,7 +134,16 @@ class colorScheme extends \zophTable {
      * @todo Maybe a custom Exception should be created.
      */
     private static function getDefault($color) {
-        $cs=array(
+        $cs = self::getDefaults();
+        if (array_key_exists($color, $cs)) {
+            return $cs[$color];
+        } else {
+            throw new \Exception("Undefined Color: " . e($color));
+        }
+    }
+
+    private static function getDefaults() {
+        return array(
             "page_bg_color"             => "#ffffff",
             "text_color"                => "#000000",
             "link_color"                => "#111111",
@@ -116,12 +158,6 @@ class colorScheme extends \zophTable {
             "selected_tab_bg_color"     => "#c0c0c0",
             "selected_tab_font_color"   => "#000000"
         );
-
-        if (array_key_exists($color, $cs)) {
-            return $cs[$color];
-        } else {
-            throw new \Exception("Undefined Color: " . e($color));
-        }
     }
 
     /**
