@@ -492,6 +492,11 @@ class template {
             array("" => "", "and" => translate("and", 0), "or" => translate("or", 0)));
     }
 
+    /**
+     * Create pulldown with variable number of days
+     * @param string name for select box
+     * @param string current value
+     */
     public static function createDaysAgoPulldown($name, $value) {
         $dt=new Time(date("Y-m-d"));
         $dateArray=array("" => "");
@@ -505,6 +510,19 @@ class template {
         return template::createPulldown($name, $value, $dateArray);
     }
 
+    /**
+     * Create pulldown with integers
+     * @param string name for select box
+     * @param string current value
+     */
+    public static function createIntegerPulldown($name, $value, $min, $max) {
+        $intArray=array();
+        for ($i = $min; $i <= $max; $i++) {
+            $intArray["$i"] = $i;
+        }
+        return template::createPulldown($name, $value, $intArray);
+    }
+
     /**
      * transforms a size in bytes into a human readable format using
      * Ki Mi Gi, etc. prefixes
