@@ -387,18 +387,23 @@ class user extends zophTable {
             translate("last ip address")    => $this->get("lastip")
         ));
 
-        if ($this->get("lightbox_id")) {
-            $lightbox = new album($this->get("lightbox_id"));
-            $lightbox->lookup();
-
-            if ($lightbox->get("album")) {
-                $da[translate("lightbox album")] = $lightbox->get("album");
+        if ($this->getLightbox()) {
+            if ($this->getLightbox()->get("album")) {
+                $da[translate("lightbox album")] = $this->getLightbox()->get("album");
             }
         }
 
         return $da;
     }
 
+    public function getLightbox() {
+        if ($this->get("lightbox_id")) {
+            $lightbox = new album($this->get("lightbox_id"));
+            $lightbox->lookup();
+            return $lightbox;
+        }
+    }
+
     public function getAccessRightsArray() {
         return array(
             "view_all_photos"       => $this->get("view_all_photos"),
