@@ -22,6 +22,7 @@
  */
 
 use conf\conf;
+use template\block;
 
 require_once "include.inc.php";
 
@@ -124,9 +125,10 @@ if ($action == "confirm") {
         <br>
         <?php echo $photo->getImageTag(MID_PREFIX); ?>
         <br>
-        <dl class "display comment">
-            <?php echo create_field_html($comment->getDisplayArray()) ?>
-        </dl>
+        <?php echo new block("definitionlist", array(
+            "class" => "display comment",
+            "dl"    => $comment->getDisplayArray()
+        )); ?>
         <br>
     </div>
     <?php
