@@ -118,7 +118,7 @@ if (!$found) {
     </textarea><br>
     <?php
     $people_string = "";
-    $people = (new photo/people($photo))->getAll();
+    $people = (new photo\people($photo))->getAll();
     if ($people) {
         $count = 0;
         foreach ($people as $person) {
