@@ -79,7 +79,7 @@ $form->addInputText("country", $place->get("country"), translate("country"),
     sprintf(translate("%s chars max"), "32"), 32);
 $form->addInputText("url", $place->get("url"), translate("url"),
     sprintf(translate("%s chars max"), "1024"), 1024, 32);
-$form->addInputText("urldesc", $place->get("urldesc"), translate("urldesc"),
+$form->addInputText("urldesc", $place->get("urldesc"), translate("url description"),
     sprintf(translate("%s chars max"), "32"), 32);
 
 $pageset=template::createPulldown("pageset", $place->get("pageset"),
