@@ -389,7 +389,7 @@ class illegalValueSecurityException extends securityException {}
 
 /**
  * Album Not Accessible Exception
- * This exception is raised when a user tries to access a photo that
+ * This exception is raised when a user tries to access an album that
  * he is not allowed to see. Since the Zoph UI hides all inaccessible
  * photos, this should only happen if the user is, for example, changing
  * parameters in the URL.
@@ -398,6 +398,17 @@ class illegalValueSecurityException extends securityException {}
  */
 class albumNotAccessibleSecurityException extends securityException {}
 
+/**
+ * Category Not Accessible Exception
+ * This exception is raised when a user tries to access a category that
+ * he is not allowed to see. Since the Zoph UI hides all inaccessible
+ * photos, this should only happen if the user is, for example, changing
+ * parameters in the URL.
+ * @author Jeroen Roos
+ * @package zophException
+ */
+class categoryNotAccessibleSecurityException extends securityException {}
+
 /**
  * Photo Not Accessible Exception
  * This exception is raised when a user tries to access a photo that
