@@ -146,10 +146,11 @@ var zImport=function() {
                 if(files.length>0) {
                     thumbswindow.style.display="block";
                     for(var i=0; i<files.length; i++) {
-                        md5=null;
-                        status=null;
-                        icon=null;
-                        var subjects=Array();
+                        md5 = null;
+                        status = null;
+                        icon = null;
+                        var subjects = Array();
+                        rating = null;
                         for(var c=0; c<files[i].childNodes.length; c++) {
                             tag=files[i].childNodes[c];
                             content=null;
@@ -171,6 +172,8 @@ var zImport=function() {
                                     subjects.push(subject);
                                 }
                                 break;
+                            case "rating":
+                                rating = parseInt(files[i].childNodes[c].textContent, 10)
                             }
                         }
                         deleteli=document.createElement("li");
@@ -281,8 +284,11 @@ var zImport=function() {
                             div.appendChild(actionlinks);
                             div.appendChild(img);
                             div.appendChild(filename);
-                            div.appendChild(categoryul);
 
+                            if (rating) {
+                                div.appendChild(zRating.rating(rating, "rating_" + md5));
+                            }
+                            div.appendChild(categoryul);
                             thumbs.appendChild(div);
                         }
                     }
@@ -444,6 +450,7 @@ var zImport=function() {
 
                 cb=images[i].name.split("_");
                 input.value=cb[1];
+                fieldset.appendChild(input);
 
                 var counter = 0
                 while ( counter != -1) {
@@ -461,7 +468,15 @@ var zImport=function() {
 
                 }
 
-                fieldset.appendChild(input);
+                var rating = document.getElementById("rating_" + cb[1]);
+                if (rating) {
+                    var ratinginput=document.createElement("input");
+
+                    ratinginput.name="_rating_" + cb[1];
+                    ratinginput.value = rating.dataset.rating;
+                    fieldset.appendChild(ratinginput);
+                }
+
                 toImport++;
             }
         }
