@@ -28,6 +28,8 @@ var zJSON=function() {
             var url="service/photoData.php?photoId=" + escape(search);
         } else if (object=='search') {
             var url="service/search.php" + search;
+        } else if (object=='photoPeople') {
+            var url="service/photoPeople.php?" + search;
         } else {
             return;
         }
