@@ -33,11 +33,6 @@ if (isset($_GET["redirect"])) {
 } else {
     $redirect = "";
 }
-if (conf::get("ssl.force") != "never") {
-    if (!array_key_exists('HTTPS', $_SERVER)) {
-        redirect(getZophURL("https") . "/logon.php?redirect=" . $redirect, "https required");
-    }
-}
 
 $user = new user();
 $lang=$user->loadLanguage();
