@@ -21,6 +21,10 @@
  * @author Jason Geiger
  * @author Jeroen Roos
  */
+
+use auth\validator;
+use conf\conf;
+
 require_once "include.inc.php";
 
 $userid = getvar("userid");
