@@ -22,6 +22,11 @@
  * @author Jeroen Roos
  */
 
+use conf\conf;
+
+use template\block;
+use template\template;
+
 require_once "include.inc.php";
 
 $_view=getvar("_view");
@@ -48,7 +53,7 @@ if (!$place->isVisible()) {
     redirect("places.php");
 }
 $obj=&$place;
-$ancestors = $place->get_ancestors();
+$ancestors = $place->getAncestors();
 $order = $user->prefs->get("child_sortorder");
 $children = $place->getChildren($order);
 $totalPhotoCount = $place->getTotalPhotoCount();
@@ -107,7 +112,7 @@ if ($showOrig) {
     <div class="main">
       <form class="viewsettings" method="get" action="places.php">
     <?php
-    echo template::createPulldown("parent_place_id", 0, place::getSelectArray($user), true);
+    echo template::createPulldown("parent_place_id", 0, place::getSelectArray(), true);
     echo create_form($request_vars, array ("_view", "_autothumb", "_button"));
     echo translate("Category view", 0) . "\n";
     echo template::createViewPulldown("_view", $_view, true);
@@ -207,10 +212,10 @@ if ($showOrig) {
     </div>
     <?php
     if (conf::get("maps.provider")) {
-        $map=new map();
+        $map=new geo\map();
         $map->setCenterAndZoomFromObj($place);
         $marker=$place->getMarker();
-        if ($marker instanceof marker) {
+        if ($marker instanceof geo\marker) {
             $map->addMarker($marker);
         }
         $map->addMarkers($children);
