@@ -23,6 +23,11 @@
  * @author Jason Geiger
  * @author Jeroen Roos
  */
+
+use conf\conf;
+
+use template\template;
+
 require_once "include.inc.php";
 
 $user=user::getCurrent();
