@@ -21,6 +21,10 @@
  * @author Jason Geiger
  * @author Jeroen Roos
  */
+
+use template\block;
+use template\template;
+
 require_once "include.inc.php";
 
 $tpl=new template("main", array(
