@@ -81,6 +81,8 @@ class settings {
         $php_loc=dirname($_SERVER['SCRIPT_FILENAME']);
         if (substr($php_loc, -8) == "/service") {
             $php_loc = substr($php_loc, 0, -8);
+        } else if (substr($php_loc, -3) == "/js") {
+            $php_loc = substr($php_loc, 0, -3);
         }
 
         foreach ($ini as $instance=>$i) {
