@@ -228,6 +228,24 @@ div.collapsed > div.ratingdetail {
     display: none;
 }
 
+div.rating {
+    position: relative;
+    margin: auto;
+    overflow: hidden;
+    bottom: 0;
+    width: 100px;
+    height: 20px;
+    background-image: url("<?= template::getImage("backgroundStar.png") ?>");
+    background-size: 20px 20px;
+}
+
+div.rating > div.stars {
+    position: absolute;
+    background-image: url("<?= template::getImage("star.png") ?>");
+    height: 20px;
+    background-size: 20px 20px;
+}
+
 div.toggle {
     width: 16px;
     height: 16px;
