@@ -30,8 +30,15 @@ if (!ZOPH) { die("Illegal call"); }
         <?php echo translate("slideshow"); ?>
     </h1>
     <div class="main">
-        <img id="butFullscreen" onclick="slideshow.fullscreen()" >
-        <img id="photo" class="photo">
+        <div class="photoframe">
+            <img id="butFullscreen">
+            <nav class="slideshow">
+                <div id="butPrev"></div>
+                <div id="butPause"></div>
+                <div id="butNext"></div>
+            </nav>
+            <img id="photo" class="photo">
+        </div>
         <div id="annotate" class="slide-annotate">
             <dl class="photodata">
                 <dt class="icon filename"><?= translate("filename") ?></dt>
