@@ -159,6 +159,11 @@ if ($action == "display") {
         $form->addPulldown($field, $pulldown, $desc[$field]);
     }
 
+    $lightbox_array = album::getSelectArray();
+    $lightbox_array["null"] = "[none]";
+    $lightbox=template::createPulldown("lightbox_id", $this_user->get("lightbox_id"), $lightbox_array);
+    $form->addPulldown("lightboxid", $lightbox, translate("lightbox album"));
+
     $tpl->addBlock($form);
 }
 echo $tpl;
